# ConnectorBaseInfoMap

A map of connector id to the basic info associated with that connector. This is useful for discovering basic properties of a connector like to which organisation is belongs. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**any string name** | [**ConnectorBaseInfo**](ConnectorBaseInfo.md) | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


